@@ -324,6 +324,12 @@ GVariant *	e_util_invoke_g_dbus_proxy_call_sync_wrapper_with_error_check
 						 const gchar *method_name,
 						 GVariant *parameters,
 						 GCancellable *cancellable);
+GVariant *	e_util_invoke_g_dbus_proxy_call_sync_wrapper
+						(GDBusProxy *dbus_proxy,
+						 const gchar *method_name,
+						 GVariant *parameters,
+						 GCancellable *cancellable,
+						 GError **error);
 GVariant *	e_util_invoke_g_dbus_proxy_call_sync_wrapper_full
 						(GDBusProxy *dbus_proxy,
 						 const gchar *method_name,
@@ -348,7 +354,21 @@ gboolean	e_util_query_ldap_root_dse_sync	(const gchar *host,
 						 gchar ***out_root_dse,
 						 GCancellable *cancellable,
 						 GError **error);
-gboolean       e_util_can_preview_filename     (const gchar *filename);
+gchar *		e_util_get_language_name	(const gchar *language_tag);
+gboolean	e_util_get_language_info	(const gchar *language_tag,
+						 gchar **out_language_name,
+						 gchar **out_country_name);
+void		e_misc_util_free_global_memory	(void);
+gboolean	e_util_can_preview_filename	(const gchar *filename);
+
+typedef struct _ESupportedLocales {
+	const gchar *code;	/* like 'en' */
+	const gchar *locale;	/* like 'en_US' */
+} ESupportedLocales;
+
+void		e_util_enum_supported_locales	(void);
+const ESupportedLocales *
+		e_util_get_supported_locales	(void);
 
 G_END_DECLS
 
